@@ -1,7 +1,7 @@
 require 'set'
+require 'tempfile'
 require 'tmpdir'
 
-require 'archive/tar/minitar'
 require 'thor'
 
 require 'debci'
@@ -51,10 +51,12 @@ module Debci
       end
 
       def save
-        File.open(tarball, 'wb') do |f|
-          Dir.chdir(repo.path) do
-            Archive::Tar::Minitar.pack(entries.sort, f)
-          end
+        files_from = Tempfile.new
+        files_from.puts(entries.sort)
+        files_from.close
+        target = File.expand_path(tarball)
+        Dir.chdir(repo.path) do
+          system('tar', 'caf', target, '--files-from=' + files_from.path)
         end
       end
     end
@@ -74,17 +76,19 @@ module Debci
         pkgs = Set.new
 
         Dir.mktmpdir do |tmpdir|
-          Archive::Tar::Minitar.unpack(tarball, tmpdir)
+          system('tar', 'xaf', tarball, '-C', tmpdir)
           Dir.chdir(tmpdir) do
+            mapping = {}
             Dir['export/*.json'].each do |json|
               jobs = JSON.parse(File.read(json))
               jobs.each do |data|
                 # load job to database
                 orig_run_id = data.delete('run_id')
-                job = Debci::Job.create!(data)
+                job = load_job(data)
 
                 pkgs.add(job.package)
 
+                mapping[orig_run_id] = job.run_id
                 puts"# loaded job: #{orig_run_id} -> #{job.run_id}"
                 if orig_run_id != job.run_id
                   # rename files to match database
@@ -107,6 +111,22 @@ module Debci
                 end
               end
             end
+
+            Dir['packages/*/*/*/*/history.json'].each do |history|
+              data = JSON.load(File.read(history))
+              data.each do |entry|
+                old_id = entry['run_id'].to_i
+                new_id = mapping[old_id]
+                if new_id
+                  entry['run_id'] = new_id
+                end
+              end
+              File.open(history, 'w') do |f|
+                f.write(JSON.pretty_generate(data))
+              end
+              puts "# rewrite #{history}"
+            end
+
           end
           puts('# copying data files ...')
           cmd = ['rsync', '-apq', '--exclude=/export', tmpdir + '/', repo.path + '/']
@@ -116,6 +136,15 @@ module Debci
         update_html(pkgs.to_a)
       end
 
+      def load_job(data)
+        job = Debci::Job.new
+        data.each do |attr, value|
+          job[attr] = value if job.attributes.key?(attr)
+        end
+        job.save!
+        job
+      end
+
       def update_html(pkgs)
         if !pkgs.empty?
           puts '# updating HTML pages ...'
