@@ -3,6 +3,7 @@ require 'debci/amqp'
 require 'debci/db'
 require 'debci/test/duration'
 require 'debci/test/expired'
+require 'debci/test/prefix'
 require 'cgi'
 require 'time'
 
@@ -11,6 +12,7 @@ module Debci
 
     include Debci::Test::Duration
     include Debci::Test::Expired
+    include Debci::Test::Prefix
 
     serialize :pin_packages, Array
 
@@ -52,12 +54,6 @@ module Debci
       ).where.not(status: nil).where(pin_packages: nil).order('date')
     end
 
-    def prefix
-      name = self.package
-      name =~ /^((lib)?.)/
-      $1
-    end
-
     # Returns the amount of time since the date for this status object
     def time
       days = (Time.now - self.created_at)/86400
@@ -91,6 +87,10 @@ module Debci
       queue.publish("%s %s %s" % [package, suite, parameters.join(' ')], priority: priority)
     end
 
+    def to_s
+      "%s %s/%s (%s)" % [package, suite, arch, status || 'pending']
+    end
+
   end
 end
 
