@@ -34,7 +34,12 @@ module Debci
 
     # Returns a Set of packages known to this debci instance
     def packages
-      @packages ||= (@data_dirs.map { |d| Dir.glob(File.join(d, '*/*')) }.flatten.map { |d| File.basename(d) } + Debci.blacklist.packages.keys).to_set
+      @packages ||= (@data_dirs.map { |d| Dir.glob(File.join(d, '*/*')) }.flatten.map { |d| File.basename(d) } + Debci.blacklist.packages).to_set.sort
+    end
+
+    # Returns a Set of packages known to this debci instance which are not blacklisted 
+    def non_blacklisted_packages
+      @non_blacklisted_packages ||= packages - Debci.blacklist.packages
     end
 
     # Returns an Array of package prefixes known to this debci instance
@@ -48,7 +53,7 @@ module Debci
     def tmpfail_packages
       tmpfail_packages = Set.new
 
-      all_statuses.each do |status|
+      all_non_blacklisted_statuses.each do |status|
         if status.status == :tmpfail
           tmpfail_packages << status.package
         end
@@ -57,8 +62,22 @@ module Debci
       tmpfail_packages.sort.map { |p| Debci::Package.new(p, self) }
     end
 
+    # Returns a Set of packages known to this debci instance that are
+    # failing. If no packages are failing, nothing is returned
+    def failing_packages
+      failing_packages = Set.new
+      
+      all_non_blacklisted_statuses.each do |status|
+        if status.status == :fail
+          failing_packages << status.package
+        end
+      end
+
+      failing_packages.sort.map { |p| Debci::Package.new(p, self) }
+    end
+
     def slow_packages
-      all_statuses.select do |status|
+      all_non_blacklisted_statuses.select do |status|
         status.duration_seconds && status.duration_seconds > 60 * 60 # 1h
       end
     end
@@ -127,8 +146,8 @@ module Debci
       match.sort.map { |p| Debci::Package.new(p, self) }
     end
 
-    # Backend implementation for Debci::Package#status
-    def status_for(package)
+    # Backend implementation for Debci::Package#all_status
+    def all_status_for(package)
       architectures.map do |arch|
         suites.map do |suite|
           status_file = File.join(data_dir(suite, arch, package), 'latest.json')
@@ -137,9 +156,19 @@ module Debci
       end
     end
 
+    # Backend implementation for Debci::Package#status
+    def status_for(package)
+      all_status_for(package).map { |r| r.reject(&:blacklisted?) }
+    end
+
+    # Backend implementation for Debci::Package#blacklisted_status
+    def blacklisted_status_for(package)
+      all_status_for(package).map { |r| r.select(&:blacklisted?) }
+    end
+
     def platform_specific_issues
       result = {}
-      packages.each do |package|
+      non_blacklisted_packages.each do |package|
         statuses = status_for(package).flatten
         if statuses.map(&:status).reject { |s| [:no_test_data, :tmpfail].include?(s) }.uniq.size > 1
           result[package] = statuses
@@ -150,14 +179,10 @@ module Debci
 
     # Backend implementation for Debci::Package#history
     def history_for(package, suite, architecture)
-      return unless File.exists?(file = File.join(data_dir(suite, architecture, package), 'history.json'))
-
-      entries = nil
-
-      File.open(file) do |f|
-        entries = JSON.load(f)
-      end
+      file = File.join(data_dir(suite, architecture, package), 'history.json')
+      return [] unless File.exists?(file)
 
+      entries = JSON.load(File.read(file))
       entries
         .map { |test| Debci::Status.from_data(test, suite, architecture) }
         .sort_by(&:date)
@@ -166,18 +191,18 @@ module Debci
 
     # Backend implementation for Debci::Package#news
     def news_for(package, n=10)
-      suites = '{' + self.suites.join(',') + '}'
-      architectures = '{' + self.architectures.join(',') + '}'
-      history = Dir.glob(File.join(data_dir(suites, architectures, package), '[0-9]*.json')).sort_by { |f| File.basename(f) }
+      history = []
+      suites.each do |suite|
+        architectures.each do |arch|
+          history += history_for(package, suite, arch)
+        end
+      end
+      history.sort_by! { |e| -e.run_id.to_i }
 
       news = []
 
       while !history.empty?
-        file = history.pop
-        dir = File.expand_path(File.dirname(file) + '/../..')
-        suite = File.basename(File.dirname(dir))
-        architecture = File.basename(dir)
-        status = load_status(file, suite, architecture)
+        status = history.shift
         if status.newsworthy?
           news << status
         end
@@ -189,6 +214,29 @@ module Debci
       news
     end
 
+    def global_news(limit = 10)
+      latest = Dir[File.join(self.path, '*/*/*/*/*/latest.json')].sort_by do |f|
+        File::Stat.new(f).mtime
+      end
+
+      news = []
+      while !latest.empty?
+        file = latest.pop
+        dir = File.expand_path(File.dirname(file) + '/../..')
+        suite = File.basename(File.dirname(dir))
+        architecture = File.basename(dir)
+        status = Debci::Status.from_file(file, suite, architecture)
+        if status.newsworthy?
+          news << status
+        end
+        if news.size >= limit
+          break
+        end
+      end
+
+      news
+    end
+
     # Returns the status history for this debci instance
     def status_history(suite, architecture)
       return unless File.exists?(file = File.join(status_dir(suite, architecture), 'history.json'))
@@ -244,6 +292,10 @@ module Debci
         end
     end
 
+    def all_non_blacklisted_statuses
+      @all_non_blacklisted_statuses ||= all_statuses.reject(&:blacklisted?)
+    end
+
   end
 
 end
