@@ -48,6 +48,7 @@ debci_backend=${debci_backend:-lxc}
 debci_data_basedir=${debci_data_basedir:-$(readlink -f "${debci_base_dir}/data")}
 debci_quiet="${debci_quiet:-false}"
 debci_amqp_server=${debci_amqp_server:-"amqp://localhost"}
+debci_amqp_tools_options=''
 debci_amqp_results_queue=${debci_amqp_results_queue:-"debci_results"}
 debci_swift_url=${debci_swift_url:-}
 debci_sendmail_from="${debci_sendmail_from:-$debci_distro_name Continuous Integration <owner@localhost>}"
@@ -164,7 +165,6 @@ debci_amqp_server_display="$(echo "$debci_amqp_server" | sed -e 's#:[^/]*@#:****
 debci_lock_dir=${debci_lock_dir:-/var/lock}
 
 # per-suite/architecture lock/timestamp files
-debci_testbed_lock=${debci_lock_dir}/debci-testbed-${debci_suite}-${debci_arch}-${debci_backend}.lock
 debci_testbed_timestamp=${debci_lock_dir}/debci-testbed-${debci_suite}-${debci_arch}-${debci_backend}.stamp
 debci_chdist_lock=${debci_lock_dir}/debci-chdist-${debci_suite}-${debci_arch}.lock
 debci_batch_lock=${debci_lock_dir}/debci-batch-${debci_suite}-${debci_arch}.lock
