@@ -123,7 +123,7 @@ describe Debci::API do
       end
     end
 
-    context 'for test a batch' do
+    context 'for a test batch' do
       it 'accepts a valid request' do
         allow_any_instance_of(Debci::Job).to receive(:enqueue)
 
@@ -152,8 +152,8 @@ describe Debci::API do
       end
 
       it 'marks blacklisted packages as failed right away' do
-        allow_any_instance_of(Debci::Blacklist).to receive(:include?).with('package1').and_return(true)
-        allow_any_instance_of(Debci::Blacklist).to receive(:include?).with('package2').and_return(false)
+        allow_any_instance_of(Debci::Blacklist).to receive(:include?).with('package1', suite: suite, arch: arch).and_return(true)
+        allow_any_instance_of(Debci::Blacklist).to receive(:include?).with('package2', suite: suite, arch: arch).and_return(false)
 
         expect_any_instance_of(Debci::Job).to receive(:enqueue).once
 
@@ -162,9 +162,11 @@ describe Debci::API do
 
         job1 = Debci::Job.find_by(package: 'package1', suite: suite, arch: arch)
         expect(job1.status).to eq('fail')
+        expect(job1.date).to_not be_nil
 
         job2 = Debci::Job.find_by(package: 'package2', suite: suite, arch: arch)
         expect(job2.status).to be_nil
+        expect(job2.date).to be_nil
       end
 
       it 'marks invalid package names as failed right away' do
@@ -206,6 +208,17 @@ describe Debci::API do
         expect(job.trigger).to eq('foo/1.0')
         expect(job.pin_packages).to eq([['src:foo', 'unstable']])
       end
+
+      batch_test_file = File.join(File.dirname(__FILE__), 'api_test_multi.json')
+
+      it 'saves everything, and only then enqueue' do
+        job = Object.new
+        expect(Debci::Job).to receive(:create!).with(anything).twice.and_return(job)
+        expect(job).to receive(:enqueue).and_raise(Exception)
+        expect do
+          post format('/api/v1/test/%<suite>s/%<arch>s', suite: suite, arch: arch), tests: Rack::Test::UploadedFile.new(batch_test_file, 'application/json')
+        end.to raise_error(Exception)
+      end
     end
   end
 
