@@ -1,14 +1,15 @@
+require "spec_helper"
 require 'debci/config'
 
 describe Debci::Config do
-
   let(:config) { Debci::Config.new }
 
   KEYS = Debci::Config.members
 
   before(:each) do
     @io = StringIO.new(KEYS.map { |k| "#{k}=value-of-#{k}\n" }.join)
-    expect(IO).to receive(:popen).with(['debci', 'config', *KEYS.map(&:to_s)]).and_yield(@io)
+    cmd = ['debci', 'config', *KEYS.map(&:to_s)]
+    expect(IO).to receive(:popen).with(cmd).and_yield(@io)
   end
 
   KEYS.each do |key|
@@ -37,9 +38,8 @@ describe Debci::Config do
   end
 
   it 'splits at the first equal sign only' do
-    url = "sqlite3:/path/to/db.sqlite3?timeout=5000"
+    url = 'sqlite3:/path/to/db.sqlite3?timeout=5000'
     @io.reopen("database_url=#{url}\n")
     expect(config.database_url).to eq(url)
   end
-
 end
