@@ -62,9 +62,10 @@ describe Debci::Status do
 
   context 'no status file' do
     before(:each) do
-      @status = from_file('does-not-exist.json')
+      @status = from_file('path/to/mypackage/does-not-exist.json')
     end
     it('Sets a status') { expect(@status.status).to eq(:no_test_data) }
+    it('Sets a package name') { expect(@status.package).to eq('mypackage') }
   end
 
   context 'news' do
@@ -185,6 +186,11 @@ describe Debci::Status do
       status = status_with(duration_seconds: 3600 + 60 + 2)
       expect(status.duration_human).to eq('1h 1m 2s')
     end
+
+    it 'handle nil' do
+      status = status_with(duration_seconds: nil)
+      expect(status.duration_human).to eq('(n/a)')
+    end
   end
 
   it 'might be blacklisted' do
