@@ -1,8 +1,16 @@
 require 'yaml'
+
+if Kernel.const_defined?('SimpleCov')
+  SimpleCov.start do
+    minimum_coverage 93.5
+  end
+end
+
 ENV['DATABASE_URL'] ||= 'sqlite3::memory:'
 require 'debci/db'
 require 'debci/job'
 
+Debci.config.backend = 'fake'
 Debci.config.quiet = true
 Debci::DB.migrate
 
