@@ -6,8 +6,11 @@ incoming=`$(dirname $0)/../bin/debci config --values-only autopkgtest_incoming_b
 
 mkdir -p "$incoming"
 
-rerun \
+./bin/debci migrate
+
+exec rerun \
   --no-notify \
+  --background \
   --exit \
   --dir "$incoming" \
   --pattern '**/exitcode' \
